@@ -1,6 +1,6 @@
 package Map::Tube::Madrid::Line::L4;
 
-$Map::Tube::Madrid::Line::L4::VERSION   = '0.39';
+$Map::Tube::Madrid::Line::L4::VERSION   = '0.40';
 $Map::Tube::Madrid::Line::L4::AUTHORITY = 'cpan:MANWAR';
 
 use 5.006;
@@ -12,7 +12,7 @@ Map::Tube::Madrid::Line::L4 - Madrid Metro Map: L4 Line.
 
 =head1 VERSION
 
-Version 0.39
+Version 0.40
 
 =encoding utf8
 
@@ -75,6 +75,10 @@ Madrid Metro Map: L4 Line.
 
 =back
 
+=head2 MAP DATA
+
+The map data for the line B<L4> collected from L<this page|https://en.wikipedia.org/wiki/Line_4_(Madrid_Metro)>.
+
 =head1 MAP
 
 Madrid Metro Map: L<L4 Line|https://raw.githubusercontent.com/manwar/Map-Tube-Madrid/master/maps/L4.png>
@@ -93,50 +97,41 @@ map generated by plugin L<Map::Tube::Plugin::Graph>.
 
 =head1 AUTHOR
 
-Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>
-
-=head1 REPOSITORY
-
-L<https://github.com/manwar/Map-Tube-Madrid>
+Mohammad Sajid Anwar, C<< <mohammad.anwar at yahoo.com> >>
 
 =head1 BUGS
 
-Please report any bugs/feature requests to C<bug-map-tube-madrid at rt.cpan.org>,
-or through the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Map-Tube-Madrid>.
-I will be notified, and then you'll automatically be notified of progress on your
+Please report any bugs or feature requests through the web interface at L<https://github.com/manwar/Map-Tube-Madrid/issues>.
+I will  be notified and then you'll automatically be notified of progress on your
 bug as I make changes.
 
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
-    perldoc Map::Tube::Madrid::Line::L4
+    perldoc Map::Tube::Madrid
 
 You can also look for information at:
 
 =over 4
 
-=item * RT: CPAN's request tracker (report bugs here)
+=item * BUG Report
 
-L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Map-Tube-Madrid>
-
-=item * AnnoCPAN: Annotated CPAN documentation
-
-L<http://annocpan.org/dist/Map-Tube-Madrid>
+L<https://github.com/manwar/Map-Tube-Madrid/issues>
 
 =item * CPAN Ratings
 
 L<http://cpanratings.perl.org/d/Map-Tube-Madrid>
 
-=item * Search CPAN
+=item * Search MetaCPAN
 
-L<http://search.cpan.org/dist/Map-Tube-Madrid/>
+L<https://metacpan.org/dist/Map-Tube-Madrid/>
 
 =back
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2018 Mohammad S Anwar.
+Copyright (C) 2018 - 2025 Mohammad Sajid Anwar.
 
 This program  is  free software; you can redistribute it and / or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a  copy of the full
